@@ -4,10 +4,12 @@ import aio_pika
 from aio_pika import Message
 from aio_pika.abc import AbstractChannel, AbstractExchange, AbstractQueue, ExchangeType
 
-from moontour_common.models import BaseRoom
+from moontour_common.models.game_messages.game_message import GameMessage
 
 RABBITMQ_HOST = os.getenv('RABBITMQ_HOST', 'rabbitmq')
 ROOMS_EXCHANGE_NAME = 'rooms'
+GAME_EXCHANGE_NAME = 'game'
+GAME_QUEUE_NAME = 'game'
 
 _channel: AbstractChannel | None = None
 
@@ -34,9 +36,22 @@ async def declare_player_queue(room_id: str, user_id: str) -> AbstractQueue:
     return queue
 
 
-async def notify_room(room: BaseRoom):
-    exchange = await get_rooms_exchange()
+async def get_game_exchange() -> AbstractExchange:
+    client = await get_rabbitmq_client()
+    return await client.declare_exchange(name='x-delayed-message', type=ExchangeType.X_DELAYED_MESSAGE)
+
+
+async def declare_game_queue() -> AbstractQueue:
+    client = await get_rabbitmq_client()
+    queue = await client.declare_queue(name=GAME_QUEUE_NAME)
+    exchange = await get_game_exchange()
+    await queue.bind(exchange, routing_key=GAME_QUEUE_NAME)
+    return queue
+
+
+async def send_game_message(game_message: GameMessage, delay: float = 0):
+    exchange = await get_game_exchange()
     await exchange.publish(
-        message=Message(body=room.json().encode()),
-        routing_key=f'{room.id}.*',
+        Message(body=game_message.json().encode(), headers={'x-delay': 1000 * delay}),
+        routing_key=GAME_QUEUE_NAME
     )
