@@ -21,3 +21,6 @@ class UserCreate(UserBase):
 
 class InternalUser(User):
     hashed_password: str
+
+    class Config(User.Config):
+        pass
